pub struct CompactVersion {
pub global_type_id: UNib32,
pub major: UNib32,
pub minor: UNib32,
pub patch: UNib32,
}Expand description
Compact version for traits-based requests that are made often or through limited bandwidth interfaces. Type id is globally unique across all crates, tracked manually via ww_global registry. NOTE: Size or structure of this type can no longer be changed without breaking compatibility, only reserved bits can still be used to carry new information.
Fields
global_type_id: UNib32major: UNib32minor: UNib32patch: UNib32Trait Implementations
Sourceimpl Clone for CompactVersion
impl Clone for CompactVersion
Sourcefn clone(&self) -> CompactVersion
fn clone(&self) -> CompactVersion
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CompactVersion
impl Debug for CompactVersion
Sourceimpl<'i> DeserializeShrinkWrap<'i> for CompactVersion
impl<'i> DeserializeShrinkWrap<'i> for CompactVersion
const ELEMENT_SIZE: ElementSize = ElementSize::UnsizedFinalStructure
fn des_shrink_wrap<'di>( rd: &'di mut BufReader<'i>, ) -> Result<Self, ShrinkWrapError>
fn from_ww_bytes(buf: &'i [u8]) -> Result<Self, Error>
Sourceimpl PartialEq for CompactVersion
impl PartialEq for CompactVersion
Sourceimpl SerializeShrinkWrap for CompactVersion
impl SerializeShrinkWrap for CompactVersion
const ELEMENT_SIZE: ElementSize = ElementSize::UnsizedFinalStructure
fn ser_shrink_wrap(&self, wr: &mut BufWriter<'_>) -> Result<(), ShrinkWrapError>
fn to_ww_bytes<'i>(&self, buf: &'i mut [u8]) -> Result<&'i [u8], Error>
impl Copy for CompactVersion
impl Eq for CompactVersion
impl StructuralPartialEq for CompactVersion